# frozen_string_literal: true

# Released under the MIT License.
# Copyright, 2024-2025, by Samuel Williams.

require_relative "console/version"
require_relative "console/captured_logger"
require_relative "console/null_logger"

# @namespace
module Sus
	# @namespace
	module Fixtures
		# @namespace
		module Console
		end
	end
end
